@@ -34,6 +34,7 @@ class AnvilRequest:
         else:
             message = f"Error: {status_code}: {response} {extra}"
 
+        # pylint: disable=broad-exception-raised
         raise Exception(message)
 
     def process_response(self, response, status_code, headers, **kwargs):
@@ -78,6 +79,12 @@ class BaseAnvilHttpRequest(AnvilRequest):
 
 
 class GraphqlRequest(AnvilRequest):
+    """Create a GraphQL request.
+
+    .. deprecated :: 2.0.0
+       Use `python_anvil.http.GQLClient` to make GraphQL queries and mutations.
+    """
+
     API_HOST = "https://graphql.useanvil.com"
 
     def __init__(self, client: HTTPClient):
